
package interfazgrafica7;

import javax.swing.ButtonGroup;
import javax.swing.JPanel;
import javax.swing.JToggleButton;

public class PanelJToggleButton extends JPanel {

      private Componentes componentes;
      
    public PanelJToggleButton(Componentes componentes) {
        this.componentes = componentes;
        ubicarComponentes();        
    }
    
    private void ubicarComponentes() {
        
        setLayout(null);
        
        componentes.setjToggleButtonLineas(new JToggleButton("Línea", true));
        componentes.getjToggleButtonLineas().setBounds(255, 45, 100, 40);
        add(componentes.getjToggleButtonLineas());
        componentes.getjToggleButtonLineas().addActionListener(componentes.getGestorEventos());
        
        componentes.setjToggleButtonRectangulos(new JToggleButton("Rectángulo", false));
        componentes.getjToggleButtonRectangulos().setBounds(255, 105, 100, 40);
        add(componentes.getjToggleButtonRectangulos());
        componentes.getjToggleButtonRectangulos().addActionListener(componentes.getGestorEventos());

        componentes.setjToggleButtonOvalos(new JToggleButton("Óvalo", false));
        componentes.getjToggleButtonOvalos().setBounds(255, 165, 100, 40);
        add(componentes.getjToggleButtonOvalos());
        componentes.getjToggleButtonOvalos().addActionListener(componentes.getGestorEventos());   
        
        ButtonGroup buttonGroup = new ButtonGroup();
        buttonGroup.add(componentes.getjToggleButtonLineas());
        buttonGroup.add(componentes.getjToggleButtonRectangulos());
        buttonGroup.add(componentes.getjToggleButtonOvalos());
    }    
}
